@@ -4,7 +4,7 @@ use bevy::{
 };
 
 use bevy_ascii_terminal::{render::TerminalTileScaling, TerminalBundle, TerminalPlugin};
-use bevy_pixel_camera::{PixelBorderPlugin, PixelCameraBundle, PixelCameraPlugin};
+use bevy_pixel_camera::{PixelCameraBundle, PixelCameraPlugin};
 
 #[derive(Default)]
 struct FontIndex(pub usize);
@@ -69,9 +69,7 @@ fn main() {
         .add_plugins(DefaultPlugins)
         .add_plugin(TerminalPlugin)
         .add_plugin(PixelCameraPlugin)
-        .add_plugin(PixelBorderPlugin {
-            color: Color::BLACK,
-        })
+        .insert_resource(ClearColor(Color::BLACK))
         .add_startup_system(spawn_terminal.system())
         .add_system(change_font.system())
         .run()
