@@ -1,7 +1,7 @@
 use bevy::prelude::*;
 use render::{
-    entity::TerminalRendererBundle, renderer_tile_data::TerminalRendererTileData,
-    renderer_vertex_data::TerminalRendererVertexData, TerminalRendererPlugin,
+    entity::TerminalRendererBundle, plugin::TerminalRendererPlugin,
+    renderer_tile_data::TerminalRendererTileData, renderer_vertex_data::TerminalRendererVertexData,
 };
 pub use terminal::{Terminal, TerminalSize};
 
