@@ -4,6 +4,7 @@ use bevy::{
         pipeline::PipelineDescriptor,
         render_graph::{base, AssetRenderResourcesNode, RenderGraph},
         shader::{ShaderStage, ShaderStages},
+        texture::ImageType,
     },
 };
 
@@ -11,11 +12,32 @@ use super::{font_data::*, AppState, *};
 
 pub const TERMINAL_RENDERER_PIPELINE: HandleUntyped =
     HandleUntyped::weak_from_u64(PipelineDescriptor::TYPE_UUID, 12121362113012541389);
+
 const VERTEX_SHADER: &str = include_str!("terminal.vert");
 const FRAGMENT_SHADER: &str = include_str!("terminal.frag");
 
 const TERMINAL_MATERIAL_NAME: &str = "terminal_mat";
 
+macro_rules! DEFAULT_FONT_PATH {
+    () => {
+        "../../data/fonts/"
+    };
+}
+pub const DEFAULT_FONT_PATH: &str = DEFAULT_FONT_PATH!();
+
+macro_rules! DEFAULT_FONT_NAME {
+    () => {
+        "alloy_curses_12x12.png"
+    };
+}
+pub const DEFAULT_FONT_NAME: &str = DEFAULT_FONT_NAME!();
+
+pub const DEFAULT_FONT_HANDLE: HandleUntyped =
+    HandleUntyped::weak_from_u64(Texture::TYPE_UUID, 12111322111012441362);
+
+const DEFAULT_FONT_BYTES: &[u8] =
+    include_bytes!(concat!(DEFAULT_FONT_PATH!(), DEFAULT_FONT_NAME!()));
+
 pub struct TerminalRendererPlugin;
 
 impl Plugin for TerminalRendererPlugin {
@@ -73,6 +95,7 @@ impl Plugin for TerminalRendererPlugin {
             .unwrap();
         let mut shaders = cell.get_resource_mut::<Assets<Shader>>().unwrap();
         let mut materials = cell.get_resource_mut::<Assets<TerminalMaterial>>().unwrap();
+        let mut textures = cell.get_resource_mut::<Assets<Texture>>().unwrap();
 
         graph.add_system_node(
             TERMINAL_MATERIAL_NAME,
@@ -93,5 +116,9 @@ impl Plugin for TerminalRendererPlugin {
         });
 
         pipelines.set_untracked(TERMINAL_RENDERER_PIPELINE, pipeline);
+
+        let tex = Texture::from_buffer(DEFAULT_FONT_BYTES, ImageType::Extension("png")).unwrap();
+
+        textures.set_untracked(DEFAULT_FONT_HANDLE, tex);
     }
 }
